@@ -15,6 +15,8 @@ from django.utils.translation import ugettext_lazy as _
 from .auth import generate_verify_email_token
 from .validators import validate_gb_phone_number
 from .MailFilter import filtered_send_mail
+from django.core import signing
+from datetime import timedelta
 
 # remove username from the default django user model. (Creating a custom user model based on the original django model)
 # email is used as the unique account 'username'
@@ -106,7 +108,23 @@ class User(AbstractBaseUser, PermissionsMixin):
             'email': self.email,
         }
 
-    def send_verification_email(self):
+    def send_verification_email(self, request):
+
+        preview = ''
+        if settings.ENABLE_PREVIEW and request.session.get('preview', None) is not None:
+            preview = '&preview'
+
+        signer = signing.TimestampSigner()
+
+        passkey = ''
+        for key in settings.PRIVATE_URL_ACCESS_KEYS:
+            if key in request.COOKIES:
+                try:
+                    signer.unsign(
+                        request.COOKIES[key], max_age=timedelta(hours=settings.PRIVATE_URL_ACCESS_TIME))
+                    passkey = f'&pass={key}'
+                except signing.BadSignature:
+                    pass
 
         token = generate_verify_email_token(self.id, self.email)
 
@@ -114,7 +132,7 @@ class User(AbstractBaseUser, PermissionsMixin):
             'first_name': self.first_name,
             'email': self.email,
             'last_name': self.last_name,
-            'verify_url': f"{settings.SITE_URL}/account/verify?token={token}"
+            'verify_url': f"{settings.SITE_URL}/account/verify?token={token}{preview}{passkey}"
         }
 
         return filtered_send_mail(
